@@ -50,8 +50,11 @@ def info_important(msg):
 
 
 def exception(e, log_message: str = "", can_print_stacktrace: bool = False):
-    logger.error(log_message + "%s, ExceptionMessage:%s", log_message, get_exception_msg(e), exc_info=can_print_stacktrace)
+    logger.error(log_message + "%s, ExceptionMessage:%s", get_exception_msg(e), exc_info=can_print_stacktrace)
 
 
 def get_exception_msg(e) -> str:
-    return getattr(e, 'message', repr(e))
+    try:
+        return getattr(e, 'message', repr(e))
+    except Exception as e:
+        return getattr(e, 'message', repr(e))
